@@ -17,10 +17,10 @@ class Preprocessor(object):
   The proteins within the proteome will be assigned numbers along with the index position of 
   each k-mer within the protein. 
 
-  Optional: protein IDs can be versioned, so the versioned_protein_ids argument can be passed
+  Optional: protein IDs can be versioned, so the versioned_ids argument can be passed
   as True to store them as versioned.
   '''
-  def __init__(self, proteome, split, preprocess_format, database='', versioned_protein_ids = False):
+  def __init__(self, proteome, split, preprocess_format, database='', smaller_proteome='', versioned_ids = False):
     if split < 2:
       raise ValueError('k-sized split is invalid. Cannot be less than 2.')
 
@@ -31,7 +31,8 @@ class Preprocessor(object):
     self.split = split
     self.preprocess_format = preprocess_format
     self.database = database
-    self.versioned_protein_ids = versioned_protein_ids
+    self.smaller_proteome = smaller_proteome
+    self.versioned_ids = versioned_ids
 
   def split_protein(self, seq, k):
     '''
@@ -66,10 +67,19 @@ class Preprocessor(object):
     kmers_table = name + '_kmers' + '_' + str(self.split)
     names_table = name + '_names'
 
+    if self.smaller_proteome != '':
+      smaller_proteome_ids = []
+      smaller_proteome = parse_fasta(self.smaller_proteome)
+      for protein in smaller_proteome:
+        protein_id = protein.id.split('|')[1]
+        if self.versioned_ids:
+          protein_id += '.' + str(protein.description).split('SV=')[1][0]
+        smaller_proteome_ids.append(protein_id)
+
     conn = sqlite3.connect(self.database)
     c = conn.cursor()
     c.execute('CREATE TABLE IF NOT EXISTS "{k}"(kmer TEXT, position INT)'.format(k = kmers_table))
-    c.execute('CREATE TABLE IF NOT EXISTS "{n}"(protein_number INT, protein_ID TEXT)'.format(n = names_table))
+    c.execute('CREATE TABLE IF NOT EXISTS "{n}"(protein_number INT, protein_id TEXT, in_smaller_proteome INT, protein_existence_level INT)'.format(n = names_table))
 
     # make a row for each unique k-mer and position mapping
     for kmer, positions in kmer_dict.items():
@@ -77,9 +87,12 @@ class Preprocessor(object):
         c.execute('INSERT INTO "{k}" (kmer, position) VALUES (?, ?)'.format(k = kmers_table), (str(kmer), position,))
 
     # make a row for each number to protein ID mapping
-    for protein_number, protein_ID in names_dict.items():
-      c.execute('INSERT INTO "{n}"(protein_number, protein_ID) VALUES(?, ?)'.format(n = names_table), 
-        (protein_number, protein_ID))
+    for protein_number, protein_data in names_dict.items():
+      
+      in_smaller_proteome = 1 if protein_data[0] in smaller_proteome_ids else 0
+      
+      c.execute('INSERT INTO "{n}"(protein_number, protein_id, in_smaller_proteome, protein_existence_level) VALUES(?, ?, ?, ?)'.format(n = names_table), 
+        (protein_number, protein_data[0], in_smaller_proteome, protein_data[1]))
 
     # create indexes for both k-mer and name tables
     c.execute('CREATE INDEX IF NOT EXISTS "{id}" ON "{k}"(kmer)'.format(id = kmers_table + '_id', k = kmers_table))
@@ -111,12 +124,13 @@ class Preprocessor(object):
           kmer_dict[kmers[i]] = [protein_count * 100000 + i]     # create entry for new k-mer
 
       # create names mapping # to protein ID (include versioned if argument is passed) 
+      protein_id = str(protein.description).split(' ')[0]
       try:
-        if self.versioned_protein_ids:
-          protein_ID = str(protein.description).split(' ')[0]
-          names_dict[protein_count] = protein_ID.split('|',1)[0] + '|' + protein_ID.split('|')[1] + '.' + str(protein.description).split('SV=')[1] + '|' + protein_ID.split('|')[2]
+        protein_existence_level = int(str(protein.description).split('PE=')[1][0])
+        if self.versioned_ids:
+          names_dict[protein_count] = (protein_id.split('|')[1] + '.' + str(protein.description).split('SV=')[1][0], protein_existence_level)
         else:
-          names_dict[protein_count] = str(protein.description).split(' ')[0]
+          names_dict[protein_count] = (protein_id.split('|')[1], protein_existence_level)
       except IndexError:
         names_dict[protein_count] = str(protein.description).split(' ')[0]
 
@@ -128,4 +142,5 @@ class Preprocessor(object):
       self.sql_proteome(kmer_dict, names_dict)
     else:
       raise AssertionError('Unexpected value of preprocessing format', self.preprocess_format)
+
     return kmer_dict, names_dict
\ No newline at end of file
